@@ -1,8 +1,9 @@
 package App::pherkin;
-$App::pherkin::VERSION = '0.37';
+$App::pherkin::VERSION = '0.38';
 use strict;
 use warnings;
 
+use lib;
 use Getopt::Long;
 use Module::Runtime qw(use_module);
 use List::Util qw(max);
@@ -26,7 +27,7 @@ App::pherkin - Run Cucumber tests from the command line
 
 =head1 VERSION
 
-version 0.37
+version 0.38
 
 =head1 SYNOPSIS
 
@@ -144,8 +145,7 @@ sub _process_arguments {
 
     # Munge the output harness
     $self->_initialize_harness( $harness || "TermColor" );
-
-    lib->import(@$includes) if @$includes;
+    lib->import( @$includes );
 
     # Store any extra step paths
     $self->step_paths($step_paths);
