@@ -1,18 +1,24 @@
 package Test::BDD::Cucumber::Harness::TestBuilder;
-$Test::BDD::Cucumber::Harness::TestBuilder::VERSION = '0.37';
+$Test::BDD::Cucumber::Harness::TestBuilder::VERSION = '0.38';
 =head1 NAME
 
 Test::BDD::Cucumber::Harness::TestBuilder - Pipes step output via Test::Builder
 
 =head1 VERSION
 
-version 0.37
+version 0.38
 
 =head1 DESCRIPTION
 
 A L<Test::BDD::Cucumber::Harness> subclass whose output is sent to
 L<Test::Builder>.
 
+=head1 OPTIONS
+
+=head2 fail_skip
+
+Boolean - makes tests with no matcher fail
+
 =cut
 
 use strict;
@@ -64,7 +70,11 @@ sub step_done {
 
     if ( $status eq 'undefined' || $status eq 'pending' ) {
         if ( $self->fail_skip ) {
-            fail("No matcher for: $step_name");
+            if ( $status eq 'undefined' ) {
+                fail("No matcher for: $step_name");
+            } else {
+                fail("Test skipped due to failure in previous step");
+            }
             $self->_note_step_data($step);
         } else {
           TODO: { todo_skip $step_name, 1 }
